#
# spec file for package python-jplephem
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-jplephem
Version:        2.22
Release:        1.2
Summary:        Planet position predictor using a JPL ephemeris
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/brandon-rhodes/python-jplephem/
Source:         https://github.com/brandon-rhodes/python-jplephem/archive/%{version}.tar.gz#/jplephem-%{version}.tar.gz
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
BuildArch:      noarch

%python_subpackages

%description
This package can load and use a Jet Propulsion Laboratory (JPL)
ephemeris for predicting the position and velocity of a planet or other
Solar System body.  It only needs NumPy <http://www.numpy.org/>`.

%prep
%setup -q -n python-jplephem-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
pushd ci
%pyunittest -v test
popd

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/jplephem
%{python_sitelib}/jplephem-%{version}.dist-info

%changelog
* Mon Apr 29 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.22
  * No changelog. Notable commit messages:
  * Move julian_day() routine to new calendar module
  * Switch to calendar dates for printing SPK segments
  * Add compute_julian_date() as a user convenience,
  * Various CI updates
* Sun Mar 24 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.21
  * Tweaked an import to avoid a fatal exception under Python 2, in
    case anyone is still using it.
- Version 2.20
  * Each segment is now protected by a lock, in case two threads
    simultaneously trigger the code that performs the initial load
    of the segment’s data; the symptom was a rare exception
    ``ValueError: cannot reshape array``.
- Version 2.19
  * Fixed a bug in the ``excerpt`` command that was causing it to
    truncate its output when the input ephemeris had more than
    about two dozen segments.  The command’s output should now
    include all matching segments from even a very large ephemeris.
  * Fixed the ``excerpt`` command so the calendar dates specified
    on the command line produce Julian dates ending with the
    fraction ``.5``, which makes excerpt endpoints more exact.
- Version 2.18
  * Added support for big-endian processors, and created a GitHub
    Actions CI build that includes both a big- and a little-endian
    architecture.
- Version 2.17
  * Fixed an ``AttributeError`` in the ``excerpt`` command.
- Version 2.16
  * Fixed a ``ValueError`` raised in the ``excerpt`` command when
    an ephemeris segment needs to be entirely skipped because it
    has no overlap with the user-specified range of dates.
  * Added a ``__version__`` constant to the package’s top level.
* Sun Feb 21 2021 Ben Greiner <code@bnavigator.de>
- Skip python36 build: With NumPy 1.20, python36-numpy is no
  longer available in Tumbleweed (NEP 29)
- Drop unused test files de405.bsp de421.bsp
* Mon Nov 16 2020 Marketa Machova <mmachova@suse.com>
- update to 2.15
  * Add "Type N" to each ephemeris segment description
  * Remove a couple of unused imports
* Thu Jul  9 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 2.14
  * Fall back to plain file I/O on platforms that support
    fileno() but that don’t support mmap(), like the Pyodide
    platform.
- Update to 2.13
  * The exception raised when a segment is given a Julian date
    outside the segment’s date range is now an instance of the
    ValueError subclass OutOfRangeError that reminds the caller
    of the range of dates supported by the SPK segment, and
    carries an array attribute indicating which input dates were
    at fault.
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 2.12
  * Replaced use of NumPy ``flip()`` with a reverse slice ``[::-1]`` after
    discovering the function was a recent addition that some user installs
    of NumPy do not support.
- Update to 2.11
  * Reverse the order in which Chebyshev polynomials are computed to
    slightly increase speed, to simplify the code, and in one case
    (comparing PCK output to NASA) to gain a partial digit of extra
    precision.
- Update to 2.10
  * Document and release support for ``.bcp`` binary PCK kernel files
    through the new ``jplephem.pck`` module.
* Thu Jan 10 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase for summary.
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.9
  * add load_array()
- Update to 2.8
  * single memory map instead of many
- Update to 2.7
  * Slight tweaks to the documentation
  * Add messages during excerpt operation
  * Add excerpt to the command line
  * Add subcommand for printing comment area
  * Add test for “daf” subcommand
  * Add subcommands to jplephem command line
  * Read as little during excerpting as possible
  * Start work on excerpt()
  * Two tweaks to write DAF files more accurately
  * Better test: array can take up only part of record
  * Slight tweaks to code
  * To fix the build,bid a fond farewell to Python 2.6
  * Git ignore tmp*.py experimental scripts
  * Full tests of DAF from BytesIO and from real file
  * Start writing a comprehensive test of DAF class
  * Avoid antipattern of attribute that shows up later
  * Add routine for writing a new DAF file summary
  * Switch DAF class to cached Struct objects
  * Introduce the idea of simply read()ing floats, too
  * Mark `ephem.py` as deprecated
  * Remove unused import
  * Make README test instructions more complete
  * Add note to README about how to run the tests
  * Add link to Skyfield to README
* Wed May 24 2017 toddrme2178@gmail.com
- Initial version
